import {
    mockParseTxWallet,
    mockAliasWallet,
    mockParseTxWalletAirdrop,
    mockParseTxWalletEncryptedMsg,
    txHistoryTokenInfoById,
    stakingRwd,
    incomingXec,
    outgoingXec,
    aliasRegistration,
    incomingEtoken,
    outgoingEtoken,
    genesisTx,
    incomingEtokenNineDecimals,
    legacyAirdropTx,
    outgoingEncryptedMsg,
    incomingEncryptedMsg,
    tokenBurn,
    tokenBurnDecimals,
    incomingEtokenTwo,
    swapTx,
    mockSwapWallet,
    aliasOffSpec,
} from './mocks';

export default {
    parseChronikTx: {
        expectedReturns: [
            {
                description: 'Staking rewards coinbase tx',
                tx: stakingRwd.tx,
                wallet: mockParseTxWallet,
                tokenInfoById: txHistoryTokenInfoById,
                parsed: stakingRwd.parsed,
            },
            {
                description: 'Incoming XEC tx',
                tx: incomingXec.tx,
                wallet: mockParseTxWallet,
                tokenInfoById: txHistoryTokenInfoById,
                parsed: incomingXec.parsed,
            },
            {
                description: 'Outgoing XEC tx',
                tx: outgoingXec.tx,
                wallet: mockParseTxWallet,
                tokenInfoById: txHistoryTokenInfoById,
                parsed: outgoingXec.parsed,
            },
            {
                description: 'Alias registration',
                tx: aliasRegistration.tx,
                wallet: mockAliasWallet,
                tokenInfoById: txHistoryTokenInfoById,
                parsed: aliasRegistration.parsed,
            },
            {
                description: 'Incoming eToken',
                tx: incomingEtoken.tx,
                wallet: mockParseTxWallet,
                tokenInfoById: txHistoryTokenInfoById,
                parsed: incomingEtoken.parsed,
            },
            {
                description: 'Outgoing eToken',
                tx: outgoingEtoken.tx,
                wallet: mockParseTxWallet,
                tokenInfoById: txHistoryTokenInfoById,
                parsed: outgoingEtoken.parsed,
            },
            {
                description: 'Genesis tx',
                tx: genesisTx.tx,
                wallet: mockParseTxWalletAirdrop,
                tokenInfoById: txHistoryTokenInfoById,
                parsed: genesisTx.parsed,
            },
            {
                description: 'Incoming eToken tx with 9 decimals',
                tx: incomingEtokenNineDecimals.tx,
                wallet: mockParseTxWalletAirdrop,
                tokenInfoById: txHistoryTokenInfoById,
                parsed: incomingEtokenNineDecimals.parsed,
            },
            {
                description: 'Legacy airdrop tx',
                tx: legacyAirdropTx.tx,
                wallet: mockParseTxWalletAirdrop,
                tokenInfoById: txHistoryTokenInfoById,
                parsed: legacyAirdropTx.parsed,
            },
            {
                description: 'Outgoing encrypted msg (deprecated)',
                tx: outgoingEncryptedMsg.tx,
                wallet: mockParseTxWalletEncryptedMsg,
                tokenInfoById: txHistoryTokenInfoById,
                parsed: outgoingEncryptedMsg.parsed,
            },
            {
                description: 'Incoming encrypted msg (deprecated)',
                tx: incomingEncryptedMsg.tx,
                wallet: mockParseTxWalletEncryptedMsg,
                tokenInfoById: txHistoryTokenInfoById,
                parsed: incomingEncryptedMsg.parsed,
            },
            {
                description: 'Token burn tx',
                tx: tokenBurn.tx,
                wallet: mockParseTxWalletAirdrop,
                tokenInfoById: txHistoryTokenInfoById,
                parsed: tokenBurn.parsed,
            },
            {
                description: 'Token burn tx with decimals',
                tx: tokenBurnDecimals.tx,
                wallet: mockParseTxWalletAirdrop,
                tokenInfoById: txHistoryTokenInfoById,
                parsed: tokenBurnDecimals.parsed,
            },
            {
                description: 'Incoming eToken tx less than zero with decimals',
                tx: incomingEtokenTwo.tx,
                wallet: mockParseTxWalletAirdrop,
                tokenInfoById: txHistoryTokenInfoById,
                parsed: incomingEtokenTwo.parsed,
            },
            {
                description: 'SWaP tx',
                tx: swapTx.tx,
                wallet: mockSwapWallet,
                tokenInfoById: txHistoryTokenInfoById,
                parsed: swapTx.parsed,
            },
            {
                description: 'Pre-spec alias registration (now off spec)',
                tx: aliasOffSpec.tx,
                wallet: mockParseTxWallet,
                tokenInfoById: txHistoryTokenInfoById,
                parsed: aliasOffSpec.parsed,
            },

            // todo current airdrop format
            // todo cashtab msg
            // todo alias bug
        ],
        expectedErrors: [],
    },
};
